==> libpcxportal-user-properties-perl_0.5-7.tar.gz: libpcxportal-user-properties-perl-0.5/UserProperties/Objects/Menu.pm <==
# Menu.pm - The Object Class that provides the Menus for UserProperties App
# Created by James A. Pattie, 02/12/2003.

# Copyright (c) 2000-2003 Xperience, Inc. http://www.pcxperience.com/
# All rights reserved.  This program is free software; you can redistribute it
# and/or modify it under the same terms as Perl itself.

package Portal::UserProperties::Objects::Menu;
use strict;
use Portal::Base;
use vars qw($AUTOLOAD $VERSION @ISA @EXPORT);

require Exporter;

@ISA = qw(Portal::Base Exporter AutoLoader);
@EXPORT = qw();

$VERSION = '0.02';

=head1 NAME

Menu - Object used to build a UserOpbject Menu Class.

=head1 SYNOPSIS

  use Portal::UserProperties::Objects::Menu;
  my $obj = Portal::UserProperties::Objects::Menu->new(methods,
                sessionObj, langObj, userObj);
  if ($obj->didErrorOccur())
  {
    die $obj->errorMessage();
  }

=head1 DESCRIPTION

Menu is a menu class.

=head1 Exported FUNCTIONS

B<NOTE>: I<bool> = 1(true), 0(false)

=over 4

=item scalar new(methods, sessionObj, langObj, userObj, portalSession)

 Creates a new instance of the Portal::UserProperties::Objects::Menu
 object.
 See Portal::Base(3) for a listing of required arguments.

 requires: methods - methods object,
           sessionObj - sessionObj for app,
           userObj - userObj for user

=cut

sub new
{
  my $class = shift;
  my $self = $class->SUPER::new(@_);
  my %args = ( methods => undef, sessionObj => undef, userObj => undef, portalSession => undef, @_ );

  if ($self->didErrorOccur)
  {
    $self->prefixError();
    return $self;
  }

  # instantiate anything unique to this module
  $self->{methods} = $args{methods};
  $self->{sessionObj} = $args{sessionObj};
  $self->{userObj} = $args{userObj};
  $self->{portalSession} = $args{portalSession};

  # do validation
  if (!$self->isValid)
  {
    # the error is set in the isValid() method.
    return $self;
  }

  # do anything else you might need to do.

  return $self;
}

=item bool isValid(void)

 Returns 0 or 1 to indicate if the object is valid.
 The error will be available via errorMessage().

=cut

sub isValid
{
  my $self = shift;

  # make sure our Parent class is valid.
  $self->SUPER::isValid();

  # validate our parameters.
  if (! defined $self->{methods})
  {
    $self->missing("methods");
  }
  if (! defined $self->{sessionObj})
  {
    $self->missing("sessionObj");
  }
  if (! defined $self->{userObj})
  {
    $self->missing("userObj");
  }
  if (! defined $self->{portalSession})
  {
    $self->missing("portalSession");
  }

  if ($self->numInvalid() > 0 || $self->numMissing() > 0)
  {
    $self->setError($self->genErrorString("all"));
    return 0;
  }

  return 1;
}

# string print(location, state, command, doc)
# requires: location - (menubar, sidemenu), state, command, doc
# returns:  generated Menubar string
# generates the specified Menu.
sub print
{
  my $self = shift;
  my %args = ( location => "menubar", state => "Main", command => "display", doc => undef, @_ );
  my $location = $args{location};
  my $state = $args{state};
  my $command = $args{command};
  my $doc = $args{doc};
  my $result = "";

  if ($location !~ /^(menubar|sidemenu)$/)
  {
    $self->invalid("location", $location);
  }
  if ($state !~ /^(Main|User)$/)
  {
    $self->invalid("state", $state);
  }
  if ($command !~ /^(.+)$/)
  {
    $self->invalid("command", $command);
  }
  if (! defined $doc)
  {
    $self->missing("doc");
  }
  if ($self->numInvalid() > 0 || $self->numMissing() > 0)
  {
    $self->setError($self->genErrorString("all"));
    return $result;
  }

  my $url = $self->{methods}->createBaseURL(type => "App", linkType => "cgi", appConfigObj => $self->{sessionObj}->{store}->{companyAppObj});
  if ($self->{methods}->didErrorOccur)
  {
    $self->setError($self->{methods}->errorMessage);
    return $result;
  }

  my $closeUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "UserProperties", state => "Main", command=> "close" });
  my $mainMenuUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "UserProperties", state => "Main", command => "display" });
  my $refreshUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "UserProperties", state => $state, command => $command });
  my $helpUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "Portal", state => "Help", command => "display", helpApp => "UserProperties", content => "Normal" . ($state ne "Main" ? ",$state" : "") });
  my $changePasswordUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "UserProperties", state => "User", command => "passwd" });
  my $userPreferencesUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "UserProperties", state => "User", command => "preferences" });
  my $userPropertiesUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "UserProperties", state => "User", command => "display" });

  my $close = $self->langObj->map("close");
  my $refresh = $self->langObj->map("refresh");
  my $help = $self->langObj->map("help");
  my $closeMessage = $self->langObj->map("closeMessage");
  my $changePasswordPhrase = $self->langObj->map("changePassword");
  my $userPreferencesPhrase = $self->langObj->map("userPreferences");
  my $userPropertiesPhrase = $self->langObj->map("userProperties");
  my $editPhrase = $self->langObj->map("edit");
  my $userPhrase = $self->langObj->map("user");

  my $mainMenu = $self->langObj->map("mainMenu");
  my $titleCommand = "";
  if ($state eq "Main")
  {
    $titleCommand = $mainMenu;
  }
  elsif ($state eq "User")
  {
    $titleCommand = ($command eq "passwd" ? $changePasswordPhrase : ($command eq "display" ? $userPropertiesPhrase : $userPreferencesPhrase));
  }
  my $title = sprintf($self->langObj->map("title"), $Portal::UserProperties::VERSION, $titleCommand);

  $doc->setTitle($title);

  # build up the menuItems arrays
  my @itemsLeft = ();
  my @itemsRight = ();
  my @itemsCenter = ();

  if ($location eq "menubar")
  {
    my $helpWindowName = "help_UserProperties_" . $self->{portalSession}->{store}->{windowTitleTimestamp};
    $itemsLeft[0] = Portal::Objects::MenuItem->new(type => "link", url => "$closeUrl", langObj => $self->{langObj},
                    text => $close, title => $close, onMouseOver => "window.status='$close'; return true;", onClick => "return validateClose();");
    $itemsLeft[1] = Portal::Objects::MenuItem->new(type => "seperator", langObj => $self->{langObj});
    $itemsLeft[2] = Portal::Objects::MenuItem->new(type => "link", url => "$helpUrl", langObj => $self->{langObj},
                    text => $help, onMouseOver => "window.status='$help'; return true;",
                    onClick => "showHelp('$helpWindowName', '$helpUrl', 480, 640); return false;", title => $help);
    $itemsLeft[3] = Portal::Objects::MenuItem->new(type => "seperator", langObj => $self->{langObj});
    $itemsLeft[4] = Portal::Objects::MenuItem->new(type => "link", url => "$refreshUrl", langObj => $self->{langObj},
                    text => $refresh, onMouseOver => "window.status='$refresh'; return true;", title => "$refresh");
    $itemsRight[0] = Portal::Objects::MenuItem->new(type => "text", text => "$userPhrase = (", langObj => $self->{langObj});
    $itemsRight[1] = Portal::Objects::MenuItem->new(type => "hilightedText", text => "$self->{userObj}->{uname}", langObj => $self->{langObj});
    $itemsRight[2] = Portal::Objects::MenuItem->new(type => "text", text => ")", langObj => $self->{langObj});

    # now validate they created ok.
    for (my $i=0; $i < scalar @itemsLeft; $i++)
    {
      if ($itemsLeft[$i]->didErrorOccur)
      {
        $self->setError("itemsLeft[$i]\n<br>" . $itemsLeft[$i]->errorMessage);
        return $result;
      }
    }
    for (my $i=0; $i < scalar @itemsRight; $i++)
    {
      if ($itemsRight[$i]->didErrorOccur)
      {
        $self->setError("itemsRight[$i]\n<br>" . $itemsRight[$i]->errorMessage);
        return $result;
      }
    }
    $result = $self->{methods}->displayMenu(doc => $doc, orientation => "horizontal",
                    itemsLeft => \@itemsLeft, itemsRight => \@itemsRight, indent => 6);
  }
  elsif ($location eq "sidemenu")
  {
    $itemsLeft[0] = Portal::Objects::MenuItem->new(type => "link", url => "$changePasswordUrl", langObj => $self->{langObj},
                    text => $changePasswordPhrase, title => $changePasswordPhrase, onMouseOver => "window.status='$changePasswordPhrase'; return true;");
    $itemsLeft[1] = Portal::Objects::MenuItem->new(type => "text", langObj => $self->{langObj},
                    text => "$editPhrase $userPropertiesPhrase");
    $itemsLeft[2] = Portal::Objects::MenuItem->new(type => "link", url => "$userPreferencesUrl", langObj => $self->{langObj},
                    text => "$editPhrase $userPreferencesPhrase", onMouseOver => "window.status='$editPhrase $userPreferencesPhrase'; return true;", title => "$editPhrase $userPreferencesPhrase");
    if ($state ne "Main")
    {
      $itemsLeft[3] = Portal::Objects::MenuItem->new(type => "seperator", langObj => $self->{langObj});
      $itemsLeft[4] = Portal::Objects::MenuItem->new(type => "link", url => "$mainMenuUrl", langObj => $self->{langObj},
                      text => $mainMenu, onMouseOver => "window.status='$mainMenu'; return true;", title => "$mainMenu");
    }

    # now validate they created ok.
    for (my $i=0; $i < scalar @itemsLeft; $i++)
    {
      if ($itemsLeft[$i]->didErrorOccur)
      {
        $self->setError("itemsLeft[$i]\n<br>" . $itemsLeft[$i]->errorMessage);
        return $result;
      }
    }
    $result = $self->{methods}->displayMenu(orientation => "vertical",
                    itemsLeft => \@itemsLeft, indent => 6);
  }
  if ($self->{methods}->didErrorOccur)
  {
    $self->setError($self->{methods}->errorMessage);
    return $result;
  }

  return $result;
}

1;
__END__

=head1 Exported FUNCTIONS (non-Inline POD)

  string print(location, state, command, doc)
    requires: location - (menubar, sidemenu), state, command, doc
    returns:  generated Menubar string
    generates the specified Menu.

=head1 NOTE

 All data fields are accessible by specifying the object
 and pointing to the data member to be modified on the
 left-hand side of the assignment.
 Ex.  $obj->variable($newValue); or $value = $obj->variable;

=head1 AUTHOR

James A. Pattie (mailto:james@pcxperience.com)

=head1 SEE ALSO

perl(1), Portal(3), Portal::UserProperties(3), Portal::Base(3)

=cut

==> libpcxportal-user-properties-perl_0.6-5.tar.gz: libpcxportal-user-properties-perl-0.6/UserProperties/Objects/Menu.pm <==
# Menu.pm - The Object Class that provides the Menus for UserProperties App
# Created by James A. Pattie, 02/12/2003.

# Copyright (c) 2000-2003 Xperience, Inc. http://www.pcxperience.com/
# All rights reserved.  This program is free software; you can redistribute it
# and/or modify it under the same terms as Perl itself.

package Portal::UserProperties::Objects::Menu;
use strict;
use Portal::Base;
use vars qw($AUTOLOAD $VERSION @ISA @EXPORT);

require Exporter;

@ISA = qw(Portal::Base Exporter AutoLoader);
@EXPORT = qw();

$VERSION = '0.02';

=head1 NAME

Menu - Object used to build a UserOpbject Menu Class.

=head1 SYNOPSIS

  use Portal::UserProperties::Objects::Menu;
  my $obj = Portal::UserProperties::Objects::Menu->new(methods,
                sessionObj, langObj, userObj);
  if ($obj->error())
  {
    die $obj->errorMessage();
  }

=head1 DESCRIPTION

Menu is a menu class.

=head1 Exported FUNCTIONS

B<NOTE>: I<bool> = 1(true), 0(false)

=over 4

=item scalar new(methods, sessionObj, langObj, userObj, portalSession)

 Creates a new instance of the Portal::UserProperties::Objects::Menu
 object.
 See Portal::Base(3) for a listing of required arguments.

 requires: methods - methods object,
           sessionObj - sessionObj for app,
           userObj - userObj for user

=cut

sub new
{
  my $class = shift;
  my $self = $class->SUPER::new(@_);
  my %args = ( methods => undef, sessionObj => undef, userObj => undef, portalSession => undef, @_ );

  if ($self->error)
  {
    $self->prefixError();
    return $self;
  }

  # instantiate anything unique to this module
  $self->{methods} = $args{methods};
  $self->{sessionObj} = $args{sessionObj};
  $self->{userObj} = $args{userObj};
  $self->{portalSession} = $args{portalSession};
  $self->{app} = (split /::/, ref $self)[1];

  # do validation
  if (!$self->isValid)
  {
    # the error is set in the isValid() method.
    return $self;
  }

  # do anything else you might need to do.

  return $self;
}

=item bool isValid(void)

 Returns 0 or 1 to indicate if the object is valid.
 The error will be available via errorMessage().

=cut

sub isValid
{
  my $self = shift;

  # make sure our Parent class is valid.
  $self->SUPER::isValid();

  # validate our parameters.
  if (! defined $self->{methods})
  {
    $self->missing("methods");
  }
  if (! defined $self->{sessionObj})
  {
    $self->missing("sessionObj");
  }
  if (! defined $self->{userObj})
  {
    $self->missing("userObj");
  }
  if (! defined $self->{portalSession})
  {
    $self->missing("portalSession");
  }

  if ($self->numInvalid() > 0 || $self->numMissing() > 0)
  {
    $self->error($self->genErrorString("all"));
    return 0;
  }

  return 1;
}

# string print(location, state, command, doc)
# requires: location - (menubar, sidemenu), state, command, doc
# returns:  generated Menubar string
# generates the specified Menu.
sub print
{
  my $self = shift;
  my %args = ( location => "menubar", state => "Main", command => "display", doc => undef, @_ );
  my $location = $args{location};
  my $state = $args{state};
  my $command = $args{command};
  my $doc = $args{doc};
  my $result = "";

  if ($location !~ /^(menubar|sidemenu)$/)
  {
    $self->invalid("location", $location);
  }
  if ($state !~ /^(Main|User)$/)
  {
    $self->invalid("state", $state);
  }
  if ($command !~ /^(.+)$/)
  {
    $self->invalid("command", $command);
  }
  if (! defined $doc)
  {
    $self->missing("doc");
  }
  if ($self->numInvalid() > 0 || $self->numMissing() > 0)
  {
    $self->error($self->genErrorString("all"));
    return $result;
  }

  my $url = $self->{methods}->createBaseURL(type => "App", linkType => "cgi", appConfigObj => $self->{sessionObj}->{store}->{companyAppObj});
  if ($self->{methods}->error)
  {
    $self->error($self->{methods}->errorMessage);
    return $result;
  }

  my $closeUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => $self->{app}, state => "Main", command=> "close" });
  my $mainMenuUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => $self->{app}, state => "Main", command => "display" });
  my $refreshUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => $self->{app}, state => $state, command => $command });
  my $helpUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => "Portal", state => "Help", command => "display", helpApp => $self->{app}, content => "Normal" . ($state ne "Main" ? ",$state" : "") });
  my $changePasswordUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => $self->{app}, state => "User", command => "changePassword" });
  my $userPreferencesUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => $self->{app}, state => "User", command => "preferences" });
  my $userInfoUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => $self->{app}, state => "User", command => "display" });
  my $editUserInfoUrl = $self->{methods}->urlBuilder(doc => $doc, baseUrl => $url, arguments => { app => $self->{app}, state => "User", command => "editUser" });

  my $close = $self->langObj->map("close");
  my $refresh = $self->langObj->map("refresh");
  my $help = $self->langObj->map("help");
  my $closeMessage = $self->langObj->map("closeMessage");
  my $changePasswordPhrase = $self->langObj->map("changePassword");
  my $userPreferencesPhrase = $self->langObj->map("userPreferences");
  my $userInfoPhrase = $self->langObj->map("userInfo");
  my $editUserInfoPhrase = $self->langObj->map("EditUserInfo");
  my $editPhrase = $self->langObj->map("edit");
  my $userPhrase = $self->langObj->map("user");

  my $mainMenu = $self->langObj->map("mainMenu");
  my $titleCommand = "";
  if ($state eq "Main")
  {
    $titleCommand = $mainMenu;
  }
  elsif ($state eq "User")
  {
    $titleCommand = ($command eq "changePassword" ? $changePasswordPhrase : ($command eq "display" ? $userInfoPhrase : $userPreferencesPhrase));
  }
  my $title = sprintf($self->langObj->map("title"), $self->{appVersion}, $titleCommand);

  $doc->setTitle($title);

  # build up the menuItems arrays
  my @itemsLeft = ();
  my @itemsRight = ();
  my @itemsCenter = ();

  if ($location eq "menubar")
  {
    my $helpWindowName = $self->{portalSession}->generateHelpWindowName($self->{app});
    if ($self->{portalSession}->error)
    {
      $self->error($self->{portalSession}->errorMessage);
      return undef;
    }
    $itemsLeft[0] = Portal::Objects::MenuItem->new(type => "link", url => "$closeUrl", langObj => $self->{langObj},
                    text => $close, title => $close, onMouseOver => "window.status='$close'; return true;", onClick => "return validateClose();");
    $itemsLeft[1] = Portal::Objects::MenuItem->new(type => "seperator", langObj => $self->{langObj});
    $itemsLeft[2] = Portal::Objects::MenuItem->new(type => "link", url => "$helpUrl", langObj => $self->{langObj},
                    text => $help, onMouseOver => "window.status='$help'; return true;",
                    onClick => "showHelp('$helpWindowName', '$helpUrl', 480, 640); return false;", title => $help);
    $itemsLeft[3] = Portal::Objects::MenuItem->new(type => "seperator", langObj => $self->{langObj});
    $itemsLeft[4] = Portal::Objects::MenuItem->new(type => "link", url => "$refreshUrl", langObj => $self->{langObj},
                    text => $refresh, onMouseOver => "window.status='$refresh'; return true;", title => "$refresh");
    $itemsRight[0] = Portal::Objects::MenuItem->new(type => "text", text => "$userPhrase = (", langObj => $self->{langObj});
    $itemsRight[1] = Portal::Objects::MenuItem->new(type => "hilightedText", text => "$self->{userObj}->{uname}", langObj => $self->{langObj});
    $itemsRight[2] = Portal::Objects::MenuItem->new(type => "text", text => ")", langObj => $self->{langObj});

    # now validate they created ok.
    for (my $i=0; $i < scalar @itemsLeft; $i++)
    {
      if ($itemsLeft[$i]->error)
      {
        $self->error("itemsLeft[$i]\n<br>" . $itemsLeft[$i]->errorMessage);
        return $result;
      }
    }
    for (my $i=0; $i < scalar @itemsRight; $i++)
    {
      if ($itemsRight[$i]->error)
      {
        $self->error("itemsRight[$i]\n<br>" . $itemsRight[$i]->errorMessage);
        return $result;
      }
    }
    $result = $self->{methods}->displayMenu(doc => $doc, orientation => "horizontal",
                    itemsLeft => \@itemsLeft, itemsRight => \@itemsRight, indent => 6);
  }
  elsif ($location eq "sidemenu")
  {
    $itemsLeft[0] = Portal::Objects::MenuItem->new(type => "link", url => "$changePasswordUrl", langObj => $self->{langObj},
                    text => $changePasswordPhrase, title => $changePasswordPhrase, onMouseOver => "window.status='$changePasswordPhrase'; return true;");
    $itemsLeft[1] = Portal::Objects::MenuItem->new(type => "link", url => "$userInfoUrl", langObj => $self->{langObj},
                    text => "$userInfoPhrase", title => $userInfoPhrase, onMouseOver => "window.status='$userInfoPhrase'; return true;");
    $itemsLeft[2] = Portal::Objects::MenuItem->new(type => "link", url => "$editUserInfoUrl", langObj => $self->{langObj},
                    text => "$editUserInfoPhrase", title => $editUserInfoPhrase, onMouseOver => "window.status='$editUserInfoPhrase'; return true;");
    $itemsLeft[3] = Portal::Objects::MenuItem->new(type => "link", url => "$userPreferencesUrl", langObj => $self->{langObj},
                    text => "$editPhrase $userPreferencesPhrase", onMouseOver => "window.status='$editPhrase $userPreferencesPhrase'; return true;", title => "$editPhrase $userPreferencesPhrase");
    if ($state ne "Main")
    {
      $itemsLeft[4] = Portal::Objects::MenuItem->new(type => "seperator", langObj => $self->{langObj});
      $itemsLeft[5] = Portal::Objects::MenuItem->new(type => "link", url => "$mainMenuUrl", langObj => $self->{langObj},
                      text => $mainMenu, onMouseOver => "window.status='$mainMenu'; return true;", title => "$mainMenu");
    }

    # now validate they created ok.
    for (my $i=0; $i < scalar @itemsLeft; $i++)
    {
      if ($itemsLeft[$i]->error)
      {
        $self->error("itemsLeft[$i]\n<br>" . $itemsLeft[$i]->errorMessage);
        return $result;
      }
    }
    $result = $self->{methods}->displayMenu(orientation => "vertical",
                    itemsLeft => \@itemsLeft, indent => 6);
  }
  if ($self->{methods}->error)
  {
    $self->error($self->{methods}->errorMessage);
    return $result;
  }

  return $result;
}

1;
__END__

=head1 Exported FUNCTIONS (non-Inline POD)

  string print(location, state, command, doc)
    requires: location - (menubar, sidemenu), state, command, doc
    returns:  generated Menubar string
    generates the specified Menu.

=head1 NOTE

 All data fields are accessible by specifying the object
 and pointing to the data member to be modified on the
 left-hand side of the assignment.
 Ex.  $obj->variable($newValue); or $value = $obj->variable;

=head1 AUTHOR

James A. Pattie (mailto:james@pcxperience.com)

=head1 SEE ALSO

perl(1), Portal(3), Portal::UserProperties(3), Portal::Base(3)

=cut
